@@ -19,12 +19,12 @@
 
 // mailclient_p.cpp isn't exported so we include it directly.
 
-#include "../mailclient_p.h"
+#include "mailclient_p.h"
 
 #include <kcalcore/incidence.h>
 #include <kcalcore/freebusy.h>
-#include <messagequeuejob.h>
-#include <kpimidentities/identity.h>
+#include <mailtransportakonadi/messagequeuejob.h>
+#include <KIdentityManagement/Identity>
 
 #include <qtest_akonadi.h>
 
@@ -41,12 +41,12 @@ Q_DECLARE_METATYPE(KCalCore::Incidence::Ptr)
 class FakeMessageQueueJob : public MailTransport::MessageQueueJob
 {
 public:
-    explicit FakeMessageQueueJob(QObject *parent = 0)
+    explicit FakeMessageQueueJob(QObject *parent = nullptr)
         : MailTransport::MessageQueueJob(parent)
     {
     }
 
-    virtual void start()
+    void start() Q_DECL_OVERRIDE
     {
         UnitTestResult unitTestResult;
         unitTestResult.message     = message();
@@ -71,12 +71,12 @@ UnitTestResult::List FakeMessageQueueJob::sUnitTestResults;
 class FakeITIPHandlerComponentFactory : public ITIPHandlerComponentFactory
 {
 public:
-    explicit FakeITIPHandlerComponentFactory(QObject *parent = 0)
+    explicit FakeITIPHandlerComponentFactory(QObject *parent = nullptr)
         : ITIPHandlerComponentFactory(parent)
     {
     }
 
-    virtual MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = 0)
+    MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) Q_DECL_OVERRIDE
     {
         Q_UNUSED(incidence);
         Q_UNUSED(identity);
@@ -439,6 +439,6 @@ private:
 
 };
 
-QTEST_AKONADIMAIN(MailClientTest, GUI)
+QTEST_AKONADIMAIN(MailClientTest)
 
 #include "mailclienttest.moc"
